# GoodGame
A Simple API for making games
# Installing
```commandline
python -m pip install goodgame
```
Note, you may use `python3` instead of `python`
# Documentation
 - See [here](https://github.com/Pyxelsuft/goodgame/tree/main/docs)
# Examples
 - [test](main.py)
# TODO
 - See [here](https://github.com/Pyxelsuft/goodgame/search?q=TODO&type=)
